@@ -6,6 +6,21 @@ Tools
 
 Utility classes for specific purpose, mainly for processing DCASE challenge submissions for publishing.
 
+DatasetPacker
+^^^^^^^^^^^^^
+
+*dcase_util.tools.DatasetPacker*
+
+DatasetPacker class can be used to create DCASE styled dataset packages where different data types delivered with
+separate packages. Large data packages are split into multiple smalled ones to ease downloading them over net.
+
+.. autosummary::
+    :toctree: generated/
+
+    DatasetPacker
+    DatasetPacker.pack
+    DatasetPacker.convert_markdown
+
 SubmissionChecker
 ^^^^^^^^^^^^^^^^^
 
@@ -18,13 +33,6 @@ SubmissionChecker class can be used to check DCASE challenge submission meta yam
 
     SubmissionChecker
     SubmissionChecker.process
-    SubmissionChecker.parameter_file
-    SubmissionChecker.system_output_file
-    SubmissionChecker.main_structure
-    SubmissionChecker.submission_info
-    SubmissionChecker.system_meta
-    SubmissionChecker.system_description
-    SubmissionChecker.system_output
 
 BibtexProcessor
 ^^^^^^^^^^^^^^^
@@ -51,5 +59,6 @@ This class provides tools to form bibtex entries for the DCASE challenge submiss
 
 from .bibtex import *
 from .submission import *
+from .datasets import *
 
 __all__ = [_ for _ in dir() if not _.startswith('_')]
